@@ -36,6 +36,7 @@ pub fn scrolling_inside_a_pane() {
     let sixel_image_store = Rc::new(RefCell::new(SixelImageStore::default()));
     let terminal_emulator_colors = Rc::new(RefCell::new(Palette::default()));
     let terminal_emulator_color_codes = Rc::new(RefCell::new(HashMap::new()));
+    let debug = false;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -49,6 +50,7 @@ pub fn scrolling_inside_a_pane() {
         terminal_emulator_color_codes,
         None,
         None,
+        debug,
     ); // 0 is the pane index
     let mut text_to_fill_pane = String::new();
     for i in 0..30 {
@@ -78,6 +80,7 @@ pub fn sixel_image_inside_terminal_pane() {
         width: 8,
         height: 21,
     })));
+    let debug = false;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -91,6 +94,7 @@ pub fn sixel_image_inside_terminal_pane() {
         terminal_emulator_color_codes,
         None,
         None,
+        debug,
     ); // 0 is the pane index
     let sixel_image_bytes = "\u{1b}Pq
         #0;2;0;0;0#1;2;100;100;0#2;2;0;100;0
@@ -120,6 +124,7 @@ pub fn partial_sixel_image_inside_terminal_pane() {
         width: 8,
         height: 21,
     })));
+    let debug = false;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -133,6 +138,7 @@ pub fn partial_sixel_image_inside_terminal_pane() {
         terminal_emulator_color_codes,
         None,
         None,
+        debug,
     ); // 0 is the pane index
     let pane_content = read_fixture("sixel-image-500px.six");
     terminal_pane.handle_pty_bytes(pane_content);
@@ -156,6 +162,7 @@ pub fn overflowing_sixel_image_inside_terminal_pane() {
         width: 8,
         height: 21,
     })));
+    let debug = false;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -169,6 +176,7 @@ pub fn overflowing_sixel_image_inside_terminal_pane() {
         terminal_emulator_color_codes,
         None,
         None,
+        debug,
     ); // 0 is the pane index
     let pane_content = read_fixture("sixel-image-500px.six");
     terminal_pane.handle_pty_bytes(pane_content);
@@ -191,6 +199,7 @@ pub fn scrolling_through_a_sixel_image() {
         width: 8,
         height: 21,
     })));
+    let debug = false;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -204,6 +213,7 @@ pub fn scrolling_through_a_sixel_image() {
         terminal_emulator_color_codes,
         None,
         None,
+        debug,
     ); // 0 is the pane index
     let mut text_to_fill_pane = String::new();
     for i in 0..30 {
@@ -237,6 +247,7 @@ pub fn multiple_sixel_images_in_pane() {
         width: 8,
         height: 21,
     })));
+    let debug = false;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -250,6 +261,7 @@ pub fn multiple_sixel_images_in_pane() {
         terminal_emulator_color_codes,
         None,
         None,
+        debug,
     ); // 0 is the pane index
     let mut text_to_fill_pane = String::new();
     for i in 0..5 {
@@ -281,6 +293,7 @@ pub fn resizing_pane_with_sixel_images() {
         width: 8,
         height: 21,
     })));
+    let debug = false;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -294,6 +307,7 @@ pub fn resizing_pane_with_sixel_images() {
         terminal_emulator_color_codes,
         None,
         None,
+        debug,
     ); // 0 is the pane index
     let mut text_to_fill_pane = String::new();
     for i in 0..5 {
@@ -328,6 +342,7 @@ pub fn changing_character_cell_size_with_sixel_images() {
         width: 8,
         height: 21,
     })));
+    let debug = false;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -341,6 +356,7 @@ pub fn changing_character_cell_size_with_sixel_images() {
         terminal_emulator_color_codes,
         None,
         None,
+        debug,
     ); // 0 is the pane index
     let mut text_to_fill_pane = String::new();
     for i in 0..5 {
@@ -380,6 +396,7 @@ pub fn keep_working_after_corrupted_sixel_image() {
         width: 8,
         height: 21,
     })));
+    let debug = false;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -393,6 +410,7 @@ pub fn keep_working_after_corrupted_sixel_image() {
         terminal_emulator_color_codes,
         None,
         None,
+        debug,
     ); // 0 is the pane index
 
     let sixel_image_bytes = "\u{1b}PI AM CORRUPTED BWAHAHAq
@@ -430,6 +448,7 @@ pub fn pane_with_frame_position_is_on_frame() {
         width: 8,
         height: 21,
     })));
+    let debug = false;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -443,6 +462,7 @@ pub fn pane_with_frame_position_is_on_frame() {
         terminal_emulator_color_codes,
         None,
         None,
+        debug,
     ); // 0 is the pane index
 
     terminal_pane.set_content_offset(Offset::frame(1));
@@ -516,6 +536,7 @@ pub fn pane_with_bottom_and_right_borders_position_is_on_frame() {
         width: 8,
         height: 21,
     })));
+    let debug = false;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -529,6 +550,7 @@ pub fn pane_with_bottom_and_right_borders_position_is_on_frame() {
         terminal_emulator_color_codes,
         None,
         None,
+        debug,
     ); // 0 is the pane index
 
     terminal_pane.set_content_offset(Offset::shift(1, 1));
@@ -602,6 +624,7 @@ pub fn frameless_pane_position_is_on_frame() {
         width: 8,
         height: 21,
     })));
+    let debug = false;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -615,6 +638,7 @@ pub fn frameless_pane_position_is_on_frame() {
         terminal_emulator_color_codes,
         None,
         None,
+        debug,
     ); // 0 is the pane index
 
     terminal_pane.set_content_offset(Offset::default());
