@@ -326,10 +326,18 @@ pub enum ScreenContext {
     NextSwapLayout,
     QueryTabNames,
     NewTiledPluginPane,
+    StartOrReloadPluginPane,
     NewFloatingPluginPane,
     AddPlugin,
     UpdatePluginLoadingStage,
     ProgressPluginLoadingOffset,
+    StartPluginLoadingIndication,
+    RequestStateUpdateForPlugins,
+    LaunchOrFocusPlugin,
+    SuppressPane,
+    FocusPaneWithId,
+    RenamePane,
+    RenameTab,
 }
 
 /// Stack call representations corresponding to the different types of [`PtyInstruction`]s.
@@ -355,12 +363,17 @@ pub enum PluginContext {
     Update,
     Render,
     Unload,
+    Reload,
     Resize,
     Exit,
     AddClient,
     RemoveClient,
     NewTab,
     ApplyCachedEvents,
+    ApplyCachedWorkerMessages,
+    PostMessageToPluginWorker,
+    PostMessageToPlugin,
+    PluginSubscribedToEvents,
 }
 
 /// Stack call representations corresponding to the different types of [`ClientInstruction`]s.
@@ -489,6 +502,9 @@ open an issue on GitHub:
 
     #[error("Client {client_id} is too slow to handle incoming messages")]
     ClientTooSlow { client_id: u16 },
+
+    #[error("The plugin does not exist")]
+    PluginDoesNotExist,
 }
 
 #[cfg(not(target_family = "wasm"))]
